% kluconf.cls -- LaTeX class for conference articles
% System Security Group, University of Klagenfurt
%
% Usage: \documentclass[<options>]{kluconf}
%
% Supported options:
%    headsepline, headnosepline, footsepline, footnosepline,
%    10pt, 11pt, 12pt, oneside, twoside, draft, final, titlepage,
%    notitlepage, onecolumn, twocolumn, leqno, fleqn, openbib,
%    abstracton, abstractoff, pointednumbers, pointlessnumbers,
%    bigheadings, normalheadings, smallheadings, liststotoc,
%    bibtotoc, bibtotocnumbered, idxtotoc, a4paper, german, english.
%
% Default options: 12pt,onecolumn,final,headsepline,footnosepline,
%    bigheadings,twoside,abstracton,a4paper,english.
%
% The 'german' option requires: german.sty
% Original document class: scrartcl.cls (KOMA-Script package).
%
%
% Last modified: 22.01.2015 Peter Schartner (Peter.Schartner@aau.at).
%
%!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
%!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
%
% *.tex --> LaTeX *.dvi
% *.dvi --> dvi2ps mit Font-embedding switches (-j0 -G0 -Pdownload35)
% *.ps  --> Distiller (Druckerei Job-Options),  bei Font-Embedding-Problem Warnung und weiter
%
% Alle Abbildungen als eps (aus PDF mittels Acrobat funktioniert meistens)
%
% Zustzliche Distiller-Optionen
% + Schriften: Wenn Einbetten fehlschlgt: "Warnen und weiter"
%   (sonst gibt es Probleme mit "Times New Roman")
%
% Acrobat-Einstellungen (Word-Plugin)
% + Einstellungen: "Lesezeichen erstellen" und "Links hinzufgen" nicht anhaken
%   (sonst werden im PDF Verknpfungen erstellt)
% + Word: "Fu- und Endnotenverknpfungen konvertieren" nicht anhaken
%   (sonst werden im PDF Verknpfungen erstellt)
%
%!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
%!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
%
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{kluconf}[2000/03/06]
\RequirePackage{colortbl} % zum Einbinden von ArialTable mit grauer berschriftzeile
\RequirePackage{times}    % Schriftart mglichst hnlich zu Word
\RequirePackage{array}    %
\RequirePackage{lastpage} % automaitsche Berechnung der letzten Seite (in Fuzeile)
\RequirePackage{ifthen}   %
%\RequirePackage{url}     %

\typeout{SYSSEC conference article document class,}
\typeout{based on the KOMA scrartcl class, 1997/11/25 v2.5c.}
\newcommand*\@ptsize{}
\newif\if@restonecol
\newif\if@titlepage
\@titlepagefalse
\newif\if@hsl
\newif\if@fsl
\newif\if@abstrt
\def\@@german{%
  \RequirePackage{german}
}
%%
\DeclareOption{headsepline}{\@hsltrue}
\DeclareOption{headnosepline}{\@hslfalse}
\DeclareOption{footsepline}{\@fsltrue}
\DeclareOption{footnosepline}{\@fslfalse}
\DeclareOption{10pt}{\renewcommand*\@ptsize{0}}
\DeclareOption{11pt}{\renewcommand*\@ptsize{1}}
\DeclareOption{12pt}{\renewcommand*\@ptsize{2}}
\DeclareOption{oneside}{\@twosidefalse \@mparswitchfalse}
\DeclareOption{twoside}{\@twosidetrue  \@mparswitchtrue}
\DeclareOption{draft}{\setlength\overfullrule{5pt}}
\DeclareOption{final}{\setlength\overfullrule{0pt}}
\DeclareOption{titlepage}{\@titlepagetrue}
\DeclareOption{notitlepage}{\@titlepagefalse}
\DeclareOption{onecolumn}{\@twocolumnfalse}
\DeclareOption{twocolumn}{\@twocolumntrue}
\DeclareOption{leqno}{\input{leqno.clo}}
\DeclareOption{fleqn}{\input{fleqn.clo}}
\DeclareOption{openbib}{%
  \AtEndOfPackage{%
   \renewcommand*\@openbib@code{%
      \advance\leftmargin\bibindent
      \itemindent -\bibindent
      \listparindent \itemindent
      \parsep \z@
      }%
   \renewcommand*\newblock{\par}}%
}
\DeclareOption{abstracton}{\@abstrttrue}
\DeclareOption{abstractoff}{\@abstrtfalse}
\DeclareOption{pointednumbers}
  {\AtEndOfClass{\@altsecnumformattrue
                 \global\let\@altsecnumformatfalse\@altsecnumformattrue}}
\DeclareOption{pointlessnumbers}
  {\AtEndOfClass{\@altsecnumformatfalse
                 \global\let\@altsecnumformattrue\@altsecnumformatfalse}}
\newcommand\@bigheadings
  {\AtEndOfClass{
    \let\size@part\Huge
    \let\size@partnumber\huge
    \let\size@section\Large
    \let\size@subsection\large
    \let\size@subsubsection\normalsize
    \let\size@paragraph\normalsize
    \let\size@subparagraph\normalsize}}
\DeclareOption{bigheadings}{\@bigheadings}
\newcommand\@normalheadings
  {\AtEndOfClass{
    \let\size@part\huge
    \let\size@partnumber\huge
    \let\size@section\large
    \let\size@subsection\normalsize
    \let\size@subsubsection\normalsize
    \let\size@paragraph\normalsize
    \let\size@subparagraph\normalsize}}
\DeclareOption{normalheadings}{\@normalheadings}
\newcommand\@smallheadings
  {\AtEndOfClass{
    \let\size@part\LARGE
    \let\size@partnumber\LARGE
    \let\size@section\normalsize
    \let\size@subsection\normalsize
    \let\size@subsubsection\normalsize
    \let\size@paragraph\normalsize
    \let\size@subparagraph\normalsize}}
\DeclareOption{smallheadings}{\@smallheadings}
\DeclareOption{liststotoc}
  {\AtEndOfClass{%
    \renewcommand*\lot@heading{%
      \addsec{\listtablename}
      \@mkboth{\listtablename}{\listtablename}}
    \renewcommand*\lof@heading{%
      \addsec{\listfigurename}
      \@mkboth{\listfigurename}{\listfigurename}}
  }}
\DeclareOption{bibtotoc}
  {\AtEndOfClass{%
    \renewcommand*\bib@heading{%
  \addsec{\refname}}
  }}
\DeclareOption{bibtotocnumbered}
  {\AtEndOfClass{%
    \renewcommand*\bib@heading{%
  \section{\refname}}
  }}
\DeclareOption{idxtotoc}
 {\AtEndOfClass{%
  \renewcommand*\idx@heading{\twocolumn[%
   \addsec{\indexname}]\@mkboth{\indexname}{\indexname}}%
  }}
\DeclareOption{a4paper}
 {\setlength\paperheight{297mm}%
  \setlength\paperwidth{210mm}%
 }
\DeclareOption{german}{\let\@german\@@german}
\DeclareOption{english}{\let\@german\relax}
\if@compatibility\else
  \DeclareOption*{\OptionNotUsed}
\fi
\ExecuteOptions{12pt,onecolumn,final,headsepline,footnosepline,bigheadings,%
twoside,abstracton,a4paper,english}
\ProcessOptions
\AtEndOfClass{\@german}
\input{size1\@ptsize.clo}
\setlength\topmargin{21mm}%
\setlength\headheight{\baselineskip}%
\if@hsl\addtolength\headheight{2\p@}\fi%
\setlength\headsep{\baselineskip}%
\if@compatibility\else
  \setlength\@tempdima{\paperheight}
  \addtolength\@tempdima{-2\topmargin}
  \addtolength\@tempdima{-\headheight}
  \addtolength\@tempdima{-\headsep}
  \divide\@tempdima\baselineskip
  \@tempcnta=\@tempdima
  \setlength\textheight{23.1cm}%\@tempcnta\baselineskip}
\fi
\setlength\oddsidemargin{25mm}%
\if@compatibility\else
  \setlength\@tempdima{\paperwidth}
  \addtolength\@tempdima{-2\oddsidemargin}
  \@settopoint\@tempdima
  \setlength\textwidth\@tempdima
\fi
%
% ps - korrekte Positionierung der grraden/ungeraden Seiten
%
\addtolength\topmargin{-19mm}%
\@settopoint\topmargin%
\addtolength\oddsidemargin{-1in}%
\@settopoint\oddsidemargin%
\setlength\evensidemargin{\oddsidemargin}%
%------------------------------------------------------------------------
%\newcommand{\titlesize}{\fontsize{24pt}{28pt}\selectfont}
%\newcommand{\authorsize}{\fontsize{16pt}{18pt}\selectfont}
%\newcommand{\addresssize}{\fontsize{14pt}{16pt}\selectfont}
%\newcommand{\abstractsize}{\fontsize{13.5pt}{15pt}\selectfont}
%\newcommand{\abstracttextsize}{\fontsize{11pt}{8pt}\selectfont}
\newcommand{\titlesize}{\fontsize{24pt}{28pt}\selectfont}
\newcommand{\authorsize}{\fontsize{16pt}{18pt}\selectfont}
\newcommand{\addresssize}{\fontsize{14pt}{16pt}\selectfont}
\newcommand{\abstractsize}{\fontsize{14pt}{15pt}\selectfont}
\newcommand{\abstracttextsize}{\fontsize{11pt}{8pt}\selectfont}
%-------------------------------------------------------------------------

\setlength\lineskip{1\p@}
\setlength\normallineskip{1\p@}
\renewcommand*\baselinestretch{}
\setlength\topskip{0.5\baselineskip}
\setlength\footskip\baselineskip
% Aus parskip.sty
\setlength\parskip{6pt \@plus 1pt \@minus 0.5pt}%
\setlength\parindent{\z@}
\def\@listI{\leftmargin\leftmargini%
   \topsep\z@ \partopsep\z@ \parsep\parskip \itemsep\z@}
\let\@listi\@listI
\@listi
\def\@listii{\leftmargin\leftmarginii%
   \labelwidth\leftmarginii \advance\labelwidth-\labelsep%
   \topsep\z@ \partopsep\z@ \parsep\parskip \itemsep\z@}
\def\@listiii{\leftmargin\leftmarginiii%
    \labelwidth\leftmarginiii\advance\labelwidth-\labelsep%
    \topsep\z@ \partopsep\z@ \parsep\parskip \itemsep\z@}
%
\@lowpenalty   51
\@medpenalty  151
\@highpenalty 301
\widowpenalty 1000                % default = 150
\displaywidowpenalty 500          % default = 50
\clubpenalty 150                  % default = 150
\emergencystretch 10pt
\setcounter{topnumber}{2}
\renewcommand*\topfraction{.7}
\setcounter{bottomnumber}{1}
\renewcommand*\bottomfraction{.3}
\setcounter{totalnumber}{3}
\renewcommand*\textfraction{.2}
\renewcommand*\floatpagefraction{.5}
\setcounter{dbltopnumber}{2}
\renewcommand*\dbltopfraction{.7}
\renewcommand*\dblfloatpagefraction{.5}
\if@compatibility
  \newcommand*\headincludeon{\@hincltrue}
  \newcommand*\headincludeoff{\@hinclfalse}
  \newcommand*\headseplineon{\@hsltrue \@hincltrue}
  \newcommand*\headseplineoff{\@hslfalse \@hinclfalse}
  \newcommand*\footincludeon{\@fincltrue}
  \newcommand*\footincludeoff{\@finclfalse}
  \newcommand*\footseplineon{\@fsltrue \@fincltrue}
  \newcommand*\footseplineoff{\@fslfalse \@finclfalse}
\fi
\def\titlemark#1{}
\if@twoside
 \def\ps@plain{\let\@mkboth\@gobbletwo
  \def\@evenhead{}%
  \def\@oddhead{a1}%
  \def\@evenfoot{}%
  \def\@oddfoot{\vbox{\hsize=\textwidth
   \if@fsl \hrule \vskip 3\p@ \fi
   \hb@xt@ \textwidth{{\pnumfont\hfil\thepage\hfil}}}}%
 }
 \def\ps@headings{\let\@mkboth\markboth
  \def\@evenhead{\vbox{\hsize=\textwidth
   \hb@xt@ \textwidth{{\pnumfont\thepage\hfil\headfont\strut\leftmark}}%
%   \if@hsl \vskip 1.5\p@ \hrule \fi}}%
%
% DACH 2010 - Position und Dicke der Linie unter der Kopfzeile
%
   \if@hsl \vskip -0.5\p@ \rule{\textwidth}{0.65pt} \fi}}%
  \def\@oddhead{\vbox{\hsize=\textwidth
   \hb@xt@ \textwidth{{\headfont\strut\rightmark\hfil\pnumfont\thepage}}%
%   \if@hsl \vskip 1.5\p@ \hrule \fi}}%
%
% DACH 2010
%
   \if@hsl \vskip -0.5\p@ \rule{\textwidth}{0.65pt} \fi}}%
  \def\@evenfoot{}%
  \def\@oddfoot{}%
  \def\sectionmark##1{}%
  \def\subsectionmark##1{}%
  \def\titlemark##1{\markboth{##1}{##1}}%
 }

 \def\ps@title{\let\@mkboth\markboth
  \def\@evenhead{}
  \def\@oddhead{}
  %alt%
  %alt% \lastpage muss manuell gesetzt werden
  %alt%
  %alt%\def\@evenfoot{\textsf{\scriptsize P.~Horster $\cdot$ P.~Schartner (Hrsg.) $\cdot$ D$^{_\bullet}\!$A$^{_\bullet}\!$CH Security 2009 $\cdot$ syssec (2009) \thepage -\@lastpage . \hfill}}%
  %alt%\def\@oddfoot{\textsf{\scriptsize P.~Horster $\cdot$ P.~Schartner (Hrsg.) $\cdot$ D$^{_\bullet}\!$A$^{_\bullet}\!$CH Security 2009 $\cdot$ syssec (2009) \thepage -\@lastpage . \hfill}}%

  %
  % automatische Berechnung der letzten Seite --> "\lastpage{...}" im Hauptdokument ggfs. auskommentieren
  %                                                                                                                                                    NICHT \number\year!
  \def\@evenfoot{\rule{0mm}{14mm}\hspace*{-1.0mm} \textsf{\scriptsize P.~Schartner \confcoeditor\ (Hrsg.) $\cdot$ D$^{_\bullet}\!$A$^{_\bullet}\!$CH Security \confyear\ $\cdot$ syssec (\confyear) \thepage -\pageref{LastPage}. \hfill}}%
  \def\@oddfoot{\rule{0mm}{14mm}\hspace*{-1.0mm}  \textsf{\scriptsize P.~Schartner \confcoeditor\ (Hrsg.) $\cdot$ D$^{_\bullet}\!$A$^{_\bullet}\!$CH Security \confyear\ $\cdot$ syssec (\confyear) \thepage -\pageref{LastPage}. \hfill}}
 }

 \def\ps@myheadings{\let\@mkboth\@gobbletwo
  \def\@evenhead{\vbox{\hsize=\textwidth
   \hb@xt@ \textwidth{{\headfont\strut\leftmark\hfil}}
   \if@hsl \vskip 1.5\p@ \hrule \fi}}%
  \def\@oddhead{\vbox{\hsize=\textwidth
   \hb@xt@ \textwidth{{\headfont\hfil\strut\rightmark}}
   \if@hsl \vskip 1.5\p@ \hrule \fi}}%
  \def\@evenfoot{\vbox{\hsize=\textwidth
   \if@fsl \hrule \vskip 3\p@ \fi
   \hb@xt@ \textwidth{{\pnumfont\thepage\hfil}}}}%
  \def\@oddfoot{\vbox{\hsize=\textwidth
   \if@fsl \hrule \vskip 3\p@ \fi
   \hb@xt@ \textwidth{{\pnumfont\hfil\thepage}}}}%
  \def\subsectionmark##1{}
  \def\sectionmark##1{}
}
\else
 \def\ps@plain{\let\@mkboth\@gobbletwo
  \def\@evenhead{}%
  \def\@oddhead{a3}%
  \def\@evenfoot{}%
  \def\@oddfoot{\vbox{\hsize=\textwidth
   \if@fsl \hrule \vskip 3\p@ \fi
   \hb@xt@ \textwidth{{\pnumfont\hfil\thepage\hfil}}}}}
 \def\ps@headings{\let\@mkboth\markboth
  \def\@evenhead{}%
  \def\@oddhead{\vbox{\hsize=\textwidth
   \hb@xt@ \textwidth{{\headfont\hfil\strut\rightmark\hfil}}
   \if@hsl \vskip 1.5\p@ \hrule \fi}}%
  \def\@evenfoot{}%
  \def\@oddfoot{\vbox{\hsize=\textwidth
   \if@fsl \hrule \vskip 3\p@ \fi
   \hb@xt@ \textwidth{{\pnumfont\hfil\thepage\hfil}}}}%
  \def\subsectionmark##1{}%
  \def\sectionmark##1{}%
  \def\titlemark##1{\markboth{##1}{##1}}%
 }
 \def\ps@myheadings{\let\@mkboth\@gobbletwo
  \def\@evenhead{}%
  \def\@oddhead{\vbox{\hsize=\textwidth
   \hb@xt@ \textwidth{{\headfont\hfil\strut\rightmark\hfil}}
   \if@hsl \vskip 1.5\p@ \hrule \fi}}%
  \def\@evenfoot{}%
  \def\@oddfoot{\vbox{\hsize=\textwidth
   \if@fsl \hrule \vskip 3\p@ \fi
   \hb@xt@ \textwidth{{\pnumfont\hfil\thepage\hfil}}}}%
  \def\subsectionmark##1{}%
  \def\sectionmark##1{}}
\fi

\newcommand*{\@extratitle}{}
\newcommand{\extratitle}[1]{\gdef\@extratitle{#1}}
\newcommand*{\@titlehead}{}
\newcommand{\titlehead}[1]{\gdef\@titlehead{#1}}
\newcommand*{\@subject}{}
\newcommand*{\subject}[1]{\gdef\@subject{#1}}
%-------------------------------------------------------------
% \renewcommand{\title}[1]{\gdef\@title{#1} \titlemark{#1}}
\renewcommand{\title}[2]{\gdef\@title{#1} \titlemark{#2}}
%-------------------------------------------------------------
\renewcommand{\and}{$\;\cdot\;$}
\newcommand*{\@authoraddress}{}
\newcommand{\authoraddress}[1]{\gdef\@authoraddress{#1}}
\newcommand*{\@uppertitleback}{}
\newcommand{\uppertitleback}[1]{\gdef\@uppertitleback{#1}}
\newcommand*{\@lowertitleback}{}
\newcommand{\lowertitleback}[1]{\gdef\@lowertitleback{#1}}
\newcommand*{\@dedication}{}
\newcommand{\dedication}[1]{\gdef\@dedication{#1}}
\newcommand*{\next@tpage}{\clearpage\thispagestyle{empty}}
\if@titlepage
    \newcommand*\maketitle[1][1]{\begin{titlepage}%
    \setcounter{page}{#1}
    \let\footnotesize\small
    \let\footnoterule\relax
    \let\footnote\thanks
    \renewcommand*\thefootnote{\@fnsymbol\c@footnote} %
    \let\@oldmakefnmark\@makefnmark
    \def\@makefnmark{\rlap\@oldmakefnmark}
    \ifx\@extratitle\@empty \else
        \noindent\@extratitle\next@tpage\cleardoublepage\thispagestyle{empty}
    \fi
    \ifx\@titlehead\@empty \else
        \noindent\begin{minipage}[t]{\textwidth}
        \@titlehead
        \end{minipage}\par
    \fi
    \null\vfill
    \begin{center}
    \ifx\@subject\@empty \else
        {\Large \@subject \par}
        \vskip 3em
    \fi
    {\sectfont\huge \@title\par}
    \vskip 3em
    {\Large \lineskip 0.75em
    \begin{tabular}[t]{c}
        \@author
    \end{tabular}\par}
    \vskip 1.5em
    {\Large \@date \par}
    \vskip \z@ \@plus3fill
    {\Large \@authoraddress \par}
    \vskip 3em
    \end{center}\par
    \@thanks
    \vfill\null
    \if@twoside\next@tpage
        \noindent\begin{minipage}[t]{\textwidth}
        \@uppertitleback
        \end{minipage}\par
        \vfill
        \noindent\begin{minipage}[b]{\textwidth}
        \@lowertitleback
        \end{minipage}
    \fi
    \ifx\@dedication\@empty \else
        \next@tpage\null\vfill
        {\centering \Large \@dedication \par}
        \vskip \z@ \@plus3fill
        \if@twoside \next@tpage\cleardoublepage \fi
    \fi
    \end{titlepage}
    \setcounter{footnote}{0}%
    \global\let\thanks\relax
    \global\let\maketitle\relax
    \global\let\@thanks\@empty
    \global\let\@author\@empty
    \global\let\@date\@empty
    \global\let\@title\@empty
    \global\let\@extratitle\@empty
    \global\let\@titlehead\@empty
    \global\let\@subject\@empty
    \global\let\@authoraddress\@empty
    \global\let\@uppertitleback\@empty
    \global\let\@lowertitleback\@empty
    \global\let\@dedication\@empty
    \global\let\author\relax
    \global\let\title\relax
    \global\let\extratitle\relax
    \global\let\titlehead\relax
    \global\let\subject\relax
    \global\let\authoraddress\relax
    \global\let\uppertitleback\relax
    \global\let\lowertitleback\relax
    \global\let\dedication\relax
    \global\let\date\relax
    \global\let\and\relax}
\else
     \newcommand*\maketitle[1][1]{%\par
       \@tempcnta=#1\relax\ifnum\@tempcnta=1\else
         \ClassWarning{kluconf}
                      {Optional argument of \string\maketitle\space ignored
                       at\MessageBreak
                       notitlepage-mode}\fi
       \begingroup
         \renewcommand*\thefootnote{\@fnsymbol\c@footnote}%
         \let\@oldmakefnmark\@makefnmark
         \def\@makefnmark{\rlap\@oldmakefnmark}
         \if@twocolumn
           \ifnum \col@number=\@ne
             \@maketitle
           \else
             \twocolumn[\@maketitle]%
           \fi
         \else
           \newpage
           \global\@topnum\z@   % Prevents figures from going at top of page.
           \@maketitle
         \fi
         \thispagestyle{title}\@thanks
       \endgroup
       \setcounter{footnote}{0}%
       \let\thanks\relax
       \let\maketitle\relax
       \let\@maketitle\relax
       \global\let\@thanks\@empty
       \global\let\@author\@empty
       \global\let\@date\@empty
       \global\let\@title\@empty
       \global\let\@extratitle\@empty
       \global\let\@titlehead\@empty
       \global\let\@subject\@empty
       \global\let\@authoraddress\@empty
       \global\let\@uppertitleback\@empty
       \global\let\@lowertitleback\@empty
       \global\let\@dedication\@empty
       \global\let\author\relax
       \global\let\title\relax
       \global\let\extratitle\relax
       \global\let\titlehead\relax
       \global\let\subject\relax
       \global\let\authoraddress\relax
       \global\let\uppertitleback\relax
       \global\let\lowertitleback\relax
       \global\let\dedication\relax
       \global\let\date\relax
       \global\let\and\relax}
\fi
\def\@maketitle{%
  \thispagestyle{title}
  \clearpage
  \let\footnote\thanks
  \begingroup
  \parskip\z@ \parsep\z@
  \ifx\@extratitle\@empty \else
      \noindent\@extratitle \next@tpage \if@twoside \null\next@tpage \fi
  \fi
  \ifx\@titlehead\@empty \else
      \noindent\begin{minipage}[t]{\textwidth}
      \@titlehead
      \end{minipage}\par
  \fi
  \begin{center}%
    \ifx\@subject\@empty \else
        {\Large \@subject \par}
        \vskip 1.5em
    \fi
%----------------------------------------------------------------
% Abstnde in der Titelseite
    {\hfill \\[-4mm] \sectfont\titlesize \@title \par}%
%
% DACH 2010
%
    \vskip 6pt% Abstand zwischen TITEL und AUTOREN
    {\authorsize
      \lineskip .5em%
      \begin{tabular}[t]{c}%
        \@author
      \end{tabular}\par}%
%
% DACH 2010
%
%    \vskip 15pt % Abstand zwischen AUTOR und AUTORADRESS
    {\addresssize \@authoraddress \par}
    \ifx\@dedication\@empty \else
        \vskip 2em
        {\Large \@dedication \par}
    \fi
  \end{center}%
  \par
%
% DACH 2010
%
%  \vskip 34pt % Abstand zwischen letzter AUTHORADRESS und ZUSAMMENFASSUNG
%  \vskip 14pt % Abstand zwischen letzter AUTHORADRESS und ZUSAMMENFASSUNG % mit \phantom{} zwischen \maketitle und \setlength{\baselineskip}{13.1pt}
  \vskip 28pt % Abstand zwischen letzter AUTHORADRESS und ZUSAMMENFASSUNG
  \endgroup
}
\renewcommand*{\numberline}[1]{%
  \hb@xt@\@tempdima{#1\if@altsecnumformat.\fi\hfil}}
\setcounter{secnumdepth}{3}
\newcounter {part}
\newcounter {section}
\newcounter {subsection}[section]
\newcounter {subsubsection}[subsection]
\newcounter {paragraph}[subsubsection]
\newcounter {subparagraph}[paragraph]
\renewcommand*\thepart          {\@Roman\c@part}
\let\@thepart\thepart
\newcommand*\@maybeasf{%
  \ifx\@thepart\thepart\global\@altsecnumformattrue\fi}
\renewcommand*\thesection       {\@arabic\c@section}
\renewcommand*\thesubsection    {\thesection.\@arabic\c@subsection}
\renewcommand*\thesubsubsection {\thesubsection.\@arabic\c@subsubsection}
\renewcommand*\theparagraph     {\thesubsubsection.\@arabic\c@paragraph}
\renewcommand*\thesubparagraph  {\theparagraph.\@arabic\c@subparagraph}
\newcommand\part{\par
   \addvspace{4ex}%
   \@afterindentfalse
   \secdef\@part\@spart}
\def\@part[#1]#2{%
    \ifnum \c@secnumdepth >\m@ne
      \refstepcounter{part}\@maybeasf%
      \addcontentsline{toc}{part}{\thepart\if@altsecnumformat.\fi%
        \hspace{1em}#1}%
    \else
      \addcontentsline{toc}{part}{#1}%
    \fi
    {\parindent \z@ \raggedright
     \interlinepenalty \@M
     \normalfont
     \ifnum \c@secnumdepth >\m@ne
       \size@partnumber\sectfont\partformat
       \par\nobreak
     \fi
     \size@part\sectfont #2%
     \sectionmark{}\par}%
     \nobreak
     \vskip 3ex
    \@afterheading}
\def\@spart#1{%
    {\parindent \z@ \raggedright
     \interlinepenalty \@M
     \normalfont
     \size@part\sectfont #1\sectionmark{}\par}%
     \nobreak
     \vskip 3ex
    \@afterheading}
\newcommand\addsec{\secdef\@addsec\@saddsec}
\def\@addsec[#1]#2{\section*{#2}\addcontentsline{toc}{section}{#1}
 \if@twoside \@mkboth{#1}{}\else \@mkboth{#1}{#1}\fi}
\def\@saddsec#1{\section*{#1}\@mkboth{}{}}
%----------------------------------------------------------------------------
% FONTSIZE von section/subsection/subsubsection/paragraph
\newcommand\section{\@startsection {section}{1}{\z@}      % letztes Argument: Abstand zum Seitenrand
                                   {-12pt \@plus -1pt \@minus -1pt}%
                                   {1pt \@minus 1pt}%
                                   {\raggedsection\fontsize{18}{14}\sectfont}} % Fontsize von SECTION (frher: \Large)
\newcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {-6pt\@plus -1pt \@minus -1pt}%
                                     {1pt \@minus 1pt}%
                                     {\raggedsection\fontsize{16}{14}\sectfont}} % Fontsize von SUBSECTION (frher: \large)
\newcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                    {-4pt\@plus -1pt \@minus -2pt}%
                                    {1pt \@minus 1pt}%
                                    {\raggedsection\large\sectfont}}             % Fontsize von SUBSECTION (frher: \normalsize)
\newcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
    {-4pt\@plus -1pt \@minus -2pt}%
    {0.1pt \@minus -6pt}%
    {\raggedsection\normalsize\sectfont}}
%ALT:
%\newcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
%  {1pt \@plus 1pt \@minus 2pt}%
%  {-1em}%
%  {\normalsize\sectfont}}
%----------------------------------------------------------------------------
\newcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
  {1pt \@plus 1pt \@minus 2pt}%
  {-1em}%
  {\normalsize\normalfont\itshape}}
\newcommand\minisec[1]{\@afterindentfalse \vskip 1.5ex
  {\parindent \z@ \raggedsection\sectfont #1\par\nobreak}%
  \@afterheading}
\let\raggedsection\raggedright
\if@twocolumn
  \setlength\leftmargini  {2em}
\else
  \setlength\leftmargini  {2.5em}
\fi
\setlength\leftmarginii  {2.2em}
\setlength\leftmarginiii {1.87em}
\setlength\leftmarginiv  {1.7em}
\if@twocolumn
  \setlength\leftmarginv  {.5em}
  \setlength\leftmarginvi {.5em}
\else
  \setlength\leftmarginv  {1em}
  \setlength\leftmarginvi {1em}
\fi
\setlength\leftmargin    {\leftmargini}
\setlength  \labelsep  {.5em}
\setlength  \labelwidth{\leftmargini}
\addtolength\labelwidth{-\labelsep}
\@beginparpenalty -\@lowpenalty
\@endparpenalty   -\@lowpenalty
\@itempenalty     -\@lowpenalty
\renewcommand*\theenumi{\@arabic\c@enumi}
\renewcommand*\theenumii{\@alph\c@enumii}
\renewcommand*\theenumiii{\@roman\c@enumiii}
\renewcommand*\theenumiv{\@Alph\c@enumiv}
\newcommand*\labelenumi{\theenumi.}
\newcommand*\labelenumii{\theenumii)}
\newcommand*\labelenumiii{\theenumiii.}
\newcommand*\labelenumiv{\theenumiv.}
\renewcommand*\p@enumii{\theenumi}
\renewcommand*\p@enumiii{\p@enumii(\theenumii)}
\renewcommand*\p@enumiv{\p@enumiii\theenumiii}
\newcommand*\labelitemi{$\m@th\bullet$}
\newcommand*\labelitemii{\normalfont\bfseries --}
\newcommand*\labelitemiii{$\m@th\triangleright$}
\newcommand*\labelitemiv{$\m@th\cdot$}

%----------------------------------------
% renew itemize & enumerate environment 1. 2. 3. ...
%----------------------------------------

\renewenvironment{itemize}
  { \begin{list}
    {$\bullet$}
    {                              \topsep=3pt \partopsep=0pt \labelwidth=10mm \leftmargin=10mm \labelsep=5.5mm
     \rightmargin=0mm \itemsep=0pt \parsep=3pt \parskip=4pt}
  }
  {\end{list}}

\newcounter{level}
\newcounter{number1}
\newcounter{number2}
\newcounter{number3}
\newcounter{number4}

\renewenvironment{enumerate}
  { \stepcounter{level}
    \begin{list}
    {
      %
      % ps
      %
      \ifthenelse{\lengthtest{\arabic{number\thelevel}pt > 9pt}}{\arabic{number\thelevel}.\hspace*{-2.0mm}}{\arabic{number\thelevel}.}
    }
    {\usecounter{number\thelevel}  \topsep=3pt \partopsep=0pt \labelwidth=1cm \leftmargin=10mm \labelsep=2.5mm
     \rightmargin=0mm \itemsep=0pt \parsep=3pt \parskip=4pt}
  }
  { \end{list}
    \addtocounter{level}{-1}
  }

%----------------------------------------
%----------------------------------------
%----------------------------------------

\newenvironment{description}
               {\list{}{\labelwidth\z@ \itemindent-\leftmargin
                        \let\makelabel\descriptionlabel}}
               {\endlist}
\newcommand*{\descriptionlabel}[1]{\hspace\labelsep
                                \descfont #1}
\newenvironment{labeling}[2][]
  {\def\sc@septext{#1}
   \list{}{\settowidth{\labelwidth}{#2#1}
     \leftmargin\labelwidth \advance\leftmargin by \labelsep
     \let\makelabel\labelinglabel}}
  {\endlist}
\newcommand\labelinglabel[1]{#1\hfil\sc@septext}
\newenvironment{verse}
               {\let\\=\@centercr
                \list{}{\itemsep      \z@
                        \itemindent   -1.5em%
                        \listparindent\itemindent
                        \rightmargin  \leftmargin
                        \advance\leftmargin 1.5em}%
                \item\relax}
               {\endlist}
\newenvironment{quotation}
               {\list{}{\listparindent 1em%
                        \itemindent    \listparindent
                        \rightmargin   \leftmargin
                        \parsep        \z@ \@plus\p@}%
                \item\relax}
               {\endlist}
\newenvironment{quote}
               {\list{}{\rightmargin\leftmargin}%
                \item\relax}
               {\endlist}

\if@titlepage
 \newenvironment{abstract}{%
     \titlepage
     \null\vfil
     \@beginparpenalty\@lowpenalty
     \if@abstrt
     \begin{center}
       \sectfont \abstractname
       \@endparpenalty\@M
     \end{center}\fi}
    {\par\vfil\null\endtitlepage}
\else
 \newenvironment{abstract}{%
     \if@twocolumn\if@abstrt
       \section*{\abstractname}\fi%
     \else
       \if@abstrt
       \begingroup
       \parskip\z@ \parsep\z@
       %\large
       \begin{center}%
         {\sectfont\abstractsize \abstractname\vspace{6pt}}%
       \end{center}
        \abstracttextsize \fi%
     \fi}
       {\if@twocolumn\else\endgroup\fi}
\fi
\newenvironment{titlepage}
    {%
      \if@twocolumn
        \@restonecoltrue\onecolumn
      \else
        \@restonecolfalse\newpage
      \fi
      \thispagestyle{empty}%
      \if@compatibility
        \setcounter{page}{0}
      \fi}%
    {\if@restonecol\twocolumn \else \newpage \fi
    }
\newcommand\marginline[1]{\marginpar[\raggedleft #1]{\raggedright #1}}
%------------------------------------------------------------
%\newcommand*\appendix{\par\global\@altsecnumformattrue
\newcommand*\appendix{\par\global\@altsecnumformatfalse
%------------------------------------------------------------
  \setcounter{section}{0}%
  \setcounter{subsection}{0}%
  \renewcommand*\thesection{\@Alph\c@section}}
\setlength\arraycolsep{5\p@}
\setlength\tabcolsep{6\p@}
\setlength\arrayrulewidth{.4\p@}
\setlength\doublerulesep{2\p@}
\setlength\tabbingsep{\labelsep}
\skip\@mpfootins = \skip\footins
\setlength\fboxsep{3\p@}
\setlength\fboxrule{.4\p@}
\renewcommand*\theequation{%
                          \@arabic\c@equation}
\newcounter{figure}
\renewcommand*\thefigure{%
                        \@arabic\c@figure}
\def\fps@figure{tbp}
\def\ftype@figure{1}
\def\ext@figure{lof}
\def\fnum@figure{\figureformat}
\newenvironment{figure}
               {\@float{figure}}
               {\end@float}
\newenvironment{figure*}
               {\@dblfloat{figure}}
               {\end@dblfloat}
\newcounter{table}
\renewcommand*\thetable{%
                       \@arabic\c@table}
\def\fps@table{tbp}
\def\ftype@table{2}
\def\ext@table{lot}
\def\fnum@table{\tableformat}
\newenvironment{table}
               {\@float{table}}
               {\end@float}
\newenvironment{table*}
               {\@dblfloat{table}}
               {\end@dblfloat}
\newlength\abovecaptionskip
\newlength\belowcaptionskip
\setlength\abovecaptionskip{10\p@}
\setlength\belowcaptionskip{0\p@}
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{{\caplabelfont #1\captionformat}{\capfont #2}}%
  \ifdim \wd\@tempboxa >\hsize
    \@hangfrom{{\caplabelfont #1\captionformat}}{\capfont #2\par}
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}
\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\DeclareOldFontCommand{\sl}{\normalfont\slshape}{\@nomath\sl}
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\@nomath\sc}
\DeclareOldFontCommand{\sfb}{\normalfont\sffamily\bfseries}{\@nomath\sfb}
\DeclareRobustCommand*\cal{\@fontswitch\relax\mathcal}
\DeclareRobustCommand*\mit{\@fontswitch\relax\mathnormal}
\newcommand*\descfont{\normalfont\bfseries}
\newcommand*\sectfont{\sffamily\bfseries}
\newcommand*\pnumfont{\normalfont}
\newcommand*\headfont{\normalfont}
\newcommand*\capfont{\small\normalfont}
\newcommand*\caplabelfont{\small\normalfont\bfseries}
\newcommand*\@pnumwidth{1.55em}
\newcommand*\@tocrmarg {2.55em}
\newcommand*\@dotsep{4.5}
\setcounter{tocdepth}{3}
\newcommand*\toc@heading{\section*{\contentsname
  \@mkboth{\contentsname}{\contentsname}}}
\newcommand*\tableofcontents{%
    \toc@heading%
    \@starttoc{toc}%
    }
\newcommand*\l@part[2]{%
  \ifnum \c@tocdepth >-2\relax
    \addpenalty{\@secpenalty}%
    \addvspace{2.25em \@plus\p@}%
    \begingroup
      \setlength\@tempdima{3em}%
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      {\leavevmode\large\sectfont
       \advance\leftskip\@tempdima
       \hskip -\leftskip
       #1\nobreak\hfil\nobreak\hb@xt@\@pnumwidth{\hss #2}}\par
       \nobreak
       \if@compatibility
         \global\@nobreaktrue
         \everypar{\global\@nobreakfalse\everypar{}}%
       \fi
    \endgroup
  \fi}
\newcommand*\l@section[2]{%
  \ifnum \c@tocdepth >\z@
    \addpenalty{\@secpenalty}%
    \addvspace{1.0em \@plus\p@}%
    \setlength\@tempdima{1.5em}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      \leavevmode \sectfont
      \advance\leftskip\@tempdima
      \hskip -\leftskip
      #1\nobreak\hfil \nobreak\hb@xt@\@pnumwidth{\hss #2}\par
    \endgroup
  \fi}
\newcommand*\l@subsection{\@dottedtocline{2}{1.5em}{2.3em}}
\newcommand*\l@subsubsection{\@dottedtocline{3}{3.8em}{3.2em}}
\newcommand*\l@paragraph{\@dottedtocline{4}{7.0em}{4.1em}}
\newcommand*\l@subparagraph{\@dottedtocline{5}{10em}{5em}}
\newcommand*\lof@heading{
  \section*{\listfigurename
  \@mkboth{\listfigurename}{\listfigurename}}}
\newcommand*\listoffigures{%
    \lof@heading%
    \@starttoc{lof}%
    }
\newcommand*\l@figure{\@dottedtocline{1}{1.5em}{2.3em}}
\newcommand*\lot@heading{%
  \section*{\listtablename
  \@mkboth{\listtablename}{\listtablename}}}
\newcommand*\listoftables{%
    \lot@heading%
    \@starttoc{lot}%
    }
\let\l@table\l@figure
\newcommand*\bib@heading{%
  \section*{\refname}}
\newdimen\bibindent
\bibindent=1.5em
\newenvironment{thebibliography}[1]{\bib@heading%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \itemsep 0\p@  \@plus1\p@ \@minus1\p@
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand*\theenumiv{\@arabic\c@enumiv}}%
      \sloppy\clubpenalty4000\widowpenalty4000%
      \sfcode`\.=\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}
\newcommand*\newblock{\hskip .11em\@plus.33em\@minus.07em}
\let\@openbib@code\@empty
\newcommand*{\idx@heading}{\twocolumn[%
  \section*{\indexname}]
    \@mkboth{\indexname}{\indexname}%
}
\newenvironment{theindex}
               {\if@twocolumn
                  \@restonecolfalse
                \else
                  \@restonecoltrue
                \fi
                \columnseprule \z@
                \columnsep 35\p@
                \idx@heading%
                \thispagestyle{plain}\parindent\z@
                \parskip\z@ \@plus .3\p@\relax
                \let\item\@idxitem}
               {\if@restonecol\onecolumn\else\clearpage\fi}
\newcommand*\@idxitem  {\par\hangindent 40\p@}
\newcommand*\subitem   {\@idxitem \hspace*{20\p@}}
\newcommand*\subsubitem{\@idxitem \hspace*{30\p@}}
\newcommand*\indexspace{\par \vskip 10\p@ \@plus5\p@ \@minus3\p@\relax}
\renewcommand*\footnoterule{%
  \kern-3\p@
%
% \hrule\@width.4\columnwidth
%
% ps - Linie vor den Funoten
%
  \hrule\@width50mm
%  \kern 2.6\p@}
%
% mehr Abstand zwischen Linie und Funotentext
%
  \kern 5.6\p@}
\newcommand\deffootnote[4][]{%
  \long\def\@makefntext##1{%
    \edef\@tempa{#1}\ifx\@tempa\@empty
      \@setpar{\@@par
        \@tempdima = \hsize
        \addtolength{\@tempdima}{-#2}
        \parshape \@ne #2 \@tempdima}%
    \else
      \@setpar{\@@par
        \@tempdima = \hsize
        \addtolength{\@tempdima}{-#1}
        \@tempdimb = \hsize
        \addtolength{\@tempdimb}{-#2}
        \parshape \tw@ #1 \@tempdima #2 \@tempdimb}%
    \fi
    \par
    \parindent #3\noindent
    \hbox to \z@{\hss\@@makefnmark}##1}
  \def\@@makefnmark{\hbox{#4}}
}
\newcommand*\deffootnotemark[1]{\def\@makefnmark{\hbox{#1}}}
\let\textsuperscript\@textsuperscript

%
% ps - Nummer der Funote
%
\def\thefootnotemark{\@thefnmark}                               % im Flietext
\def\thenewfootnotemark{\parbox{1.25em}{\@thefnmark \hfill}}    % in der Funote

%         [Einrckung]{}{Breite der Nummer}
\deffootnote[1.25em]{0em}{1em}{\textsuperscript{\normalfont\thenewfootnotemark}\hspace*{0.25em}}
\deffootnotemark{\textsuperscript{\normalfont\thefootnotemark}}

\newcommand*\contentsname{Contents}
\newcommand*\listfigurename{List of Figures}
\newcommand*\listtablename{List of Tables}
\newcommand*\refname{References}
\newcommand*\indexname{Index}
\newcommand*\figurename{Figure}
\newcommand*\tablename{Table}
\newcommand*\partname{Part}
\newcommand*\appendixname{Appendix}
\newcommand*\abstractname{Abstract}
\newcommand*\today{\ifcase\month\or
  January\or February\or March\or April\or May\or June\or
  July\or August\or September\or October\or November\or December\fi
  \space\number\day, \number\year}
\newif\if@altsecnumformat\@altsecnumformatfalse
\AtEndDocument{\if@altsecnumformat\if@filesw
    \immediate\write\@auxout{\string\global\string\@altsecnumformattrue}
  \fi\fi}
\newcommand*\sectionmarkformat    {\thesection\if@altsecnumformat.\fi\quad}
\newcommand*\subsectionmarkformat {\thesubsection\if@altsecnumformat.\fi\quad}
\newcommand*\partformat    {\partname~\thepart\if@altsecnumformat.\fi\ }
%\newcommand*\figureformat  {\figurename~\thefigure}
%\newcommand*\tableformat   {\tablename~\thetable}
%
% Abb. und Tab. hardcoded :-)
%
\newcommand*\figureformat  {Abb.~\thefigure}
\newcommand*\tableformat   {Tab.~\thetable}
\newcommand*\captionformat {:\ }

%
% weniger Abstand zwischen Bild und Unterschrift
%
\newcommand{\figcaption}[1]{\vspace*{-3mm}\caption{#1}}

%------------------------------------------------------------------------------------------
% Abstnde von Aufzhlung zur berschrift (section, subsection etc.)
\renewcommand*{\@seccntformat}[1]{%
  \csname the#1\endcsname\if@altsecnumformat.\fi\hspace{4mm}} % Abstand von Nummerierung zur berschrift
%------------------------------------------------------------------------------------------

\setlength\columnsep{10\p@}
\setlength\columnseprule{0\p@}
\pagestyle{headings}
\pagenumbering{arabic}      % Arabic page numbers
\if@twoside
\else
     \raggedbottom
\fi
\if@twocolumn
  \twocolumn
  \sloppy
  \flushbottom
\else
  \onecolumn
\fi

% --------------------------- ArialTable BEGINN ------------------------------------------
\definecolor{Gray}{gray}{0.85}
\newcolumntype{G}{>{\columncolor{Gray}}c} % macht eine graue Spalte
\newcommand{\DLine}[1]{\hline\multicolumn{#1}{|c|}{\vspace{-4mm}}\\\hline} % macht eine Doppellinie
\setlength{\extrarowheight}{3pt}
\newcommand{\ArialTableSize}{\fontsize{10pt}{10pt}\selectfont}
\newcommand{\ArialTable}[3]{
\begin{table}[h!]
\begin{center}
%\caption{#1}\label{#2}\vspace{4mm} {\fontfamily{phv}\selectfont
%
% weniger Abstand zwischen berschrift und Tabelle
%
\caption{#1}\label{#2}\vspace{1mm} {\fontfamily{phv}\selectfont
\begin{ArialTableSize}
#3
\end{ArialTableSize}}
\end{center}
\end{table}}
% --------------------------- ArialTable ENDE --------------------------------------------

\newcommand{\url}[1]{\linebreak[1]\normalfont #1}
\newcommand{\urlprefix}[2]{\linebreak[1]\normalfont}
\def\UrlFont{\linebreak[1]\normalfont}
\newcommand{\us}{$\underline{\hspace*{2mm}}$}
\renewcommand{\refname}{\fontsize{14pt}{16pt}\selectfont Literatur \normalfont}

\endinput
